@@ -1,6 +1,6 @@
 package Facebook::Graph;
 {
-  $Facebook::Graph::VERSION = '1.0502';
+  $Facebook::Graph::VERSION = '1.0600';
 }
 
 use Any::Moose;
@@ -10,6 +10,7 @@ use Facebook::Graph::AccessToken;
 use Facebook::Graph::Authorize;
 use Facebook::Graph::Query;
 use Facebook::Graph::Picture;
+use Facebook::Graph::Request;
 use Facebook::Graph::Publish::Post;
 use Facebook::Graph::Publish::Photo;
 use Facebook::Graph::Publish::Checkin;
@@ -102,6 +103,11 @@ sub fql {
     return $self->query->find('fql')->search($query)->request->as_hashref;
 }
 
+sub request {
+    my ($self, $uri) = @_;
+    return Facebook::Graph::Request->new->get($uri)->recv;
+}
+
 sub query {
     my ($self) = @_;
     my %params = ( );
@@ -290,7 +296,7 @@ Facebook::Graph - A fast and easy way to integrate your apps with Facebook.
 
 =head1 VERSION
 
-version 1.0502
+version 1.0600
 
 =head1 SYNOPSIS
 
@@ -318,10 +324,7 @@ You can also do asynchronous calls like this:
 
 Or fetching a response from a URI you already have:
 
- my $hashref = $fb->query
-    ->request('https://graph.facebook.com/btaylor')
-    ->as_hashref;
-    
+ my $hashref = $fb->request('https://graph.facebook.com/btaylor')->as_hashref;
 
 
 =head2 Building A Privileged App
@@ -416,6 +419,13 @@ An authorization code string that you should have gotten by going through the C<
 
 Creates a L<Facebook::Graph::Query> object, which can be used to fetch and search data from Facebook.
 
+=head2 request ( uri )
+
+Fetch a Facebook::Graph URI you already have.
+
+=head3 uri
+
+The URI to fetch. For example: https://graph.facebook.com/amazon
 
 =head2 fetch ( id )
 
